@@ -285,7 +285,7 @@ class BaseParameterWrapper(dict):
                 }
 
             # Skip data type transformation if the list is empty or None values
-            if value == [None,] * len(value):
+            if value == [None, ] * len(value):
                 return value
             if value == []:
                 return None
@@ -296,8 +296,8 @@ class BaseParameterWrapper(dict):
                     correct_value = value
 
                 if dict_units[label] is float:
-                    correct_value  = [float(v) if not v is None else v
-                    for v in value]
+                    correct_value = [float(v) if not v is None else v
+                                     for v in value]
 
                 if dict_units[label] is simtk.unit.quantity.Quantity:
                     correct_value = string_to_quantity(value)
@@ -1200,6 +1200,12 @@ class OPLS2005ParameterWrapper(BaseParameterWrapper):
 
         params['charges'] = unit.Quantity(charges, unit.elementary_charge)
 
+        # Check params is not empty (it would mean that ffld_server failed)
+        if len(params['atom_types']) == 0:
+            raise ValueError(f"ffld server did not produce a valid output. " +
+                             f"Instead, the following output was obtained: " +
+                             f"{ffld_output}")
+
         opls_parameters_wrapper = OPLS2005ParameterWrapper(params)
         OPLS2005ParameterWrapper._add_SGBNP_solvent_parameters(
             opls_parameters_wrapper)
