@@ -101,6 +101,7 @@ class Topology(object):
         """It builds the atoms of the molecule."""
 
         from peleffy.utils import Logger
+        from peleffy.topology.rotamer import CoreLessMolecularGraph
         logger = Logger()
 
         coords = RDKitToolkitWrapper().get_coordinates(self.molecule)
@@ -123,6 +124,13 @@ class Topology(object):
                         nonpolar_alpha=alpha)
             self.add_atom(atom)
 
+        if isinstance(self.molecule.graph, CoreLessMolecularGraph):
+            message = f'Error: core-less molecular graph cannot be ' + \
+                f'used to build a non-alchemic topology for ' + \
+                f'molecule {self.molecule.name}'
+            logger.error([message])
+            raise TypeError(message)
+
         for atom in self.atoms:
             if atom.index in self.molecule.graph.core_nodes:
                 atom.set_as_core()
@@ -136,16 +144,16 @@ class Topology(object):
                 absolute_parent = atom.index
                 break
         else:
-            logger.error('Error: no core atom found in molecule '
-                         + '{}'.format(self.molecule.name))
+            logger.error(['Error: no core atom found in molecule ' +
+                          f'{self.molecule.name}'])
 
         # Get parent indexes from the molecular graph
         parent_idxs = self.molecule.graph.get_parents(absolute_parent)
 
         # Assert parent_idxs has right length
         if len(parent_idxs) != len(self.atoms):
-            logger.error('Error: no core atom found in molecule '
-                         + '{}'.format(self.molecule.name))
+            logger.error(['Error: invalid number of parents obtained for ' +
+                          f'{self.molecule.name}'])
 
         for atom in self.atoms:
             parent_idx = parent_idxs[atom.index]
